@@ -2,12 +2,17 @@ import glob
 import importlib
 import importlib.util
 import os
+import pathlib
 
 import pcraft.functions
 
 class Functions:
-    def __init__(self, plugins_data, functionsdir="pcraft/functions/"):
+    def __init__(self, plugins_data, functionsdir=None):
         self.loaded_functions = {}
+        self.instdir = str(pathlib.Path(__file__).parent.absolute())
+        if functionsdir == None:
+            functionsdir = self.instdir + "/functions/"
+            
         self.functions = glob.glob(functionsdir + "*.py")
         self.functions = [x for x in self.functions if not x.endswith("__init__.py")] # I do not want to include the __init__.py file
         self.functions = [x for x in self.functions if not x.endswith("_utils.py")]
@@ -18,6 +23,7 @@ class Functions:
         for modfile in self.functions:
             function_name = os.path.basename(modfile)[:-3] # We remove the extension
             import_function = self._modularize_string_path(modfile)
+            import_function = "pcraft" + import_function[len(self.instdir):]
             module = importlib.import_module(import_function)
             dp = module.PCraftFunction(plugins_data)
             self.loaded_functions[function_name] = dp
