@@ -2,6 +2,7 @@ import glob
 import importlib
 import importlib.util
 import os
+import pathlib
 
 import pcraft.plugins
 from pcraft.Application import *
@@ -9,9 +10,13 @@ from pcraft.PluginsData import *
 from pcraft.Sessionizer import *
 
 class Plugins:
-    def __init__(self, pluginsdir="pcraft/plugins/", app=None, arguments_dealer=None, loadfunc=None):
+    def __init__(self, pluginsdir=None, app=None, arguments_dealer=None, loadfunc=None):
         self.loaded_plugins = {}
         self.arguments_dealer = arguments_dealer
+        self.instdir = str(pathlib.Path(__file__).parent.absolute())
+        if pluginsdir == None:
+            pluginsdir = self.instdir + "/plugins/"
+            
         self.plugins = glob.glob(pluginsdir + "*.py")
         self.plugins = [x for x in self.plugins if not x.endswith("__init__.py")] # I do not want to include the __init__.py file
         self.plugins = [x for x in self.plugins if not x.endswith("_utils.py")]
@@ -26,6 +31,7 @@ class Plugins:
         for modfile in self.plugins:
             plugin_name = os.path.basename(modfile)[:-3] # We remove the extension
             import_plugin = self._modularize_string_path(modfile)
+            import_plugin = "pcraft" + import_plugin[len(self.instdir):]
             module = importlib.import_module(import_plugin)
             dp = module.PCraftPlugin(self.app, self.session, self.plugins_data)
             self.loaded_plugins[plugin_name] = dp
